/* 
  specific_S12232ZA.h
  
  This file is part of Monochrome Graphic LCD library (MGLCD) for Arduino
  Uno/Mega 2560.
  
  MGLCD developed by Synapse from 2012 to 2013.  This Library is originally 
  distributed at Team Schaft's Homepage. <http://www3.big.or.jp/~schaft>

  MGLCD is now under beta testing, so specification may be changed 
  in the future.

  MGLCD is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 2.1 of the License, or
  (at your option) any later version.

  MGLCD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with MGLCD.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef SPECIFIC_S12232ZA_H
#define SPECIFIC_S12232ZA_H

#include <arduino.h>

#if MGLCD_VERSION != 30
#error versions of this file and header file are different.
#endif

class specific_S12232ZA
{
public :
  static const unsigned char Width = 122; // Screen Width
  static const unsigned char Height = 32; // Screen Height
  static const unsigned char HalfWidth = Width/2; // Half of screen width
  static const unsigned char PageNum = Height/8; // Number of character lines
  static const unsigned char ColumnNum = Width/MGLCD_FONT_WIDTH; // Number of character columns
  static const unsigned char DisplayOnCommand     = 0xaf;
  static const unsigned char DisplayOffCommand    = 0xae;
  static const unsigned char DisplayLineCommand   = 0xc0;
  static const unsigned char PageAddressCommand   = 0xb8;
  static const unsigned char ColumnAddressCommand = 0x00;
  static const boolean EPinUsed = false;

  static unsigned char (*const GeneralReadData )(unsigned char ctrl, const TPinSet &PinSet);
  static unsigned char (*const StandardReadData)(unsigned char ctrl, const TPinSet &PinSet);
  static void (*const GeneralWriteData )(unsigned char ctrl, unsigned char data, const TPinSet &PinSet);
  static void (*const StandardWriteData)(unsigned char ctrl, unsigned char data, const TPinSet &PinSet);

  TPinSet PinSet;
  unsigned char (*ReadData)(unsigned char ctrl, const TPinSet &PinSet);
  void (*WriteData)(unsigned char ctrl, unsigned char data, const TPinSet &PinSet);

  void Reset(void);
}; // specific_S12232ZA

typedef mglcd_direct<specific_S12232ZA> mglcd_S12232ZA;

#endif // #ifndef SPECIFIC_SG12232ZA_H
